MethodChannelAirwallexPaymentFlutter class

An implementation of AirwallexPaymentFlutterPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialize(Environment environment, bool enableLogging, bool saveLogToLocal) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parsePaymentResult(Map<String, dynamic>? result) → PaymentResult
payWithCardDetails(BaseSession session, Card card, bool saveCard) → Future<PaymentResult>
override
payWithConsent(BaseSession session, PaymentConsent consent) → Future<PaymentResult>
override
presentCardPaymentFlow(BaseSession session, {List<CardBrand>? supportedBrands}) → Future<PaymentResult>
override
presentEntirePaymentFlow(BaseSession session, {PaymentSheetConfiguration? configuration}) → Future<PaymentResult>
override
setTintColor(Color color) → void
override
startApplePay(BaseSession session) → Future<PaymentResult>
override
startGooglePay(BaseSession session) → Future<PaymentResult>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited