BillingAddress class

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

BillingAddress({String? city, String? countryCode, String? street, String? postcode, String? state})
BillingAddress.fromJson(Map<String, dynamic> json)
factory

Properties

city ↔ String?
getter/setter pair
countryCode ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
postcode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
getter/setter pair
street ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited