Shipping class

Customer shipping (and billing, when reused via PaymentMethod.billing) details pre-filled into the payment sheet.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Shipping({String? firstName, String? lastName, String? phoneNumber, String? shippingMethod, String? email, String? dateOfBirth, ShippingAddress? address})
Shipping.fromJson(Map<String, dynamic> json)
factory

Properties

address ↔ ShippingAddress?
getter/setter pair
dateOfBirth ↔ String?
getter/setter pair
email ↔ String?
getter/setter pair
firstName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastName ↔ String?
getter/setter pair
phoneNumber ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingMethod ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited