Card class

Card details. When used as input to payWithCardDetails, the merchant supplies number, expiryMonth, expiryYear, cvc, and optionally name.

The remaining fields (bin, last4, brand, fingerprint, cvcCheck, avsCheck, etc.) are populated by Airwallex when a Card is returned as part of a saved payment method on a PaymentConsent.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

Card({String? cvc, String? expiryMonth, String? expiryYear, String? name, String? number, String? bin, String? last4, String? brand, String? country, String? funding, String? fingerprint, String? cvcCheck, String? avsCheck, String? issuerCountryCode, String? numberType})
Card.fromJson(Map<String, dynamic> json)
factory

Properties

avsCheck String?
getter/setter pair
bin String?
getter/setter pair
brand String?
getter/setter pair
country String?
getter/setter pair
cvc String?
getter/setter pair
cvcCheck String?
getter/setter pair
expiryMonth String?
getter/setter pair
expiryYear String?
getter/setter pair
fingerprint String?
getter/setter pair
funding String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
issuerCountryCode String?
getter/setter pair
last4 String?
getter/setter pair
name String?
getter/setter pair
number String?
getter/setter pair
numberType String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited